lambeq.core package
===================

Submodules
----------

lambeq.core.types module
------------------------

.. automodule:: lambeq.core.types
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: lambeq.core
   :members:
   :undoc-members:
   :show-inheritance:
